@@ -1,3 +1,23 @@
+summarypoint<-function(x, var, fun="mean", freq=NULL, dates = NULL, months= NULL, ...) {
+  if(!inherits(x,"data.frame")) stop("'x' has to be a data.frame.")
+  VARS = c("MeanTemperature", "MinTemperature","MaxTemperature", "Precipitation",
+           "MeanRelativeHumidity", "MinRelativeHumidity", "MaxRelativeHumidity",
+           "Radiation", "WindSpeed", "WindDirection", "PET")
+  var = match.arg(var, VARS)
+  
+  if(is.null(dates)) dates = as.Date(row.names(x))
+  if(!is.null(months)) {
+    m = as.numeric(format(dates,"%m"))
+    dates = dates[m %in% months]
+  }
+  if(is.null(freq)) {
+    df =  do.call(fun, args=list(x[as.character(dates),var],...))
+  } else {
+    date.factor = cut(dates, breaks=freq)
+    df = tapply(x[as.character(dates),var],INDEX=date.factor, FUN=fun,...)
+  }
+  return(df)
+}
 summarypoints<-function(points, var, fun=mean, freq=NULL, dates = NULL, months = NULL, ...) {
   if(!inherits(points,"SpatialPointsMeteorology") && !inherits(points,"SpatialPointsDataFrame")) stop("'points' has to be of class 'SpatialPointsMeteorology' or 'SpatialPointsDataFrame'.")
   VARS = c("MeanTemperature", "MinTemperature","MaxTemperature", "Precipitation",
@@ -32,17 +52,7 @@ summarypoints<-function(points, var, fun=mean, freq=NULL, dates = NULL, months =
         obs = readmeteorologypoint(f)
       }
     }
-    if(is.null(dates)) dates = as.Date(row.names(obs))
-    if(!is.null(months)) {
-      m = as.numeric(format(dates,"%m"))
-      dates = dates[m %in% months]
-    }
-    if(is.null(freq)) {
-      dfvec[[i]] =  do.call(fun, args=list(obs[as.character(dates),var],...))
-    } else {
-      date.factor = cut(dates, breaks=freq)
-      dfvec[[i]] = tapply(obs[as.character(dates),var],INDEX=date.factor, FUN=fun,...)
-    }
+    dfvec[[i]] = summarypoint(obs,var,fun, freq, dates,months,...)
   }
   cat("\n")
   noutvars = length(dfvec[[1]])
